package com.fjhx.customer.service.xiaoman.impl;

import com.baomidou.dynamic.datasource.annotation.DSTransactional;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fjhx.customer.entity.xiaoman.po.XiaomanCustomer;
import com.fjhx.customer.entity.xiaoman.po.XiaomanCustomerInfoJson;
import com.fjhx.customer.entity.xiaoman.vo.CustomerApiVo;
import com.fjhx.customer.entity.xiaoman.vo.CustomerInfoVo;
import com.fjhx.customer.entity.xiaoman.vo.CustomerListApiVo;
import com.fjhx.customer.handle.HandleXiaomanData;
import com.fjhx.customer.handle.R;
import com.fjhx.customer.mapper.xiaoman.XiaomanCustomerMapper;
import com.fjhx.customer.service.xiaoman.XiaomanCustomerInfoJsonService;
import com.fjhx.customer.service.xiaoman.XiaomanCustomerService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fjhx.customer.entity.xiaoman.vo.XiaomanCustomerVo;
import com.fjhx.customer.entity.xiaoman.dto.XiaomanCustomerSelectDto;
import com.ruoyi.common.utils.wrapper.IWrapper;
import com.fjhx.customer.entity.xiaoman.dto.XiaomanCustomerDto;
import cn.hutool.core.bean.BeanUtil;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import static com.ruoyi.common.utils.wrapper.IWrapper.getWrapper;

/**
 * <p>
 * 小满客户表 服务实现类
 * </p>
 *
 * @author lqh
 * @since 2024-04-06
 */
@Service
public class XiaomanCustomerServiceImpl extends ServiceImpl<XiaomanCustomerMapper, XiaomanCustomer> implements XiaomanCustomerService {

    @Resource
    private XiaomanCustomerInfoJsonServiceImpl xiaomanCustomerInfoJsonService;

    @Override
    public List<XiaomanCustomerVo> getList(XiaomanCustomerSelectDto dto) {
        IWrapper<XiaomanCustomer> wrapper = getWrapper();
        wrapper.orderByDesc("xc", XiaomanCustomer::getCompanyId);
        List<XiaomanCustomerVo> list = this.baseMapper.getList(wrapper);
        return list;
    }

    @Override
    public Page<XiaomanCustomerVo> getPage(XiaomanCustomerSelectDto dto) {
        IWrapper<XiaomanCustomer> wrapper = getWrapper();
        wrapper.orderByDesc("xc", XiaomanCustomer::getCompanyId);
        Page<XiaomanCustomerVo> page = this.baseMapper.getPage(dto.getPage(), wrapper);
        return page;
    }

    @Override
    public XiaomanCustomerVo detail(Long id) {
        XiaomanCustomer XiaomanCustomer = this.getById(id);
        XiaomanCustomerVo result = BeanUtil.toBean(XiaomanCustomer, XiaomanCustomerVo.class);
        return result;
    }

    @Override
    public void add(XiaomanCustomerDto xiaomanCustomerDto) {
        this.save(xiaomanCustomerDto);
    }

    @Override
    public void edit(XiaomanCustomerDto xiaomanCustomerDto) {
        this.updateById(xiaomanCustomerDto);
    }

    @Override
    public void delete(Long id) {
        this.removeById(id);
    }

    @Override
    public void handleSaveOrUpdate(List<CustomerApiVo> customerApiVoList, Set<Long> allCustomer) {
        List<XiaomanCustomer> xiaomanCustomerList = new ArrayList<>(customerApiVoList);
        for (XiaomanCustomer customer : xiaomanCustomerList){
            try {
                if (allCustomer.contains(customer.getCompanyId())){
                    updateById(customer);
                    //TODO 获取详情
                    String customerDetailJson = HandleXiaomanData.getCustomerDetail(customer.getCompanyId());
                    XiaomanCustomerInfoJson xiaomanCustomerInfoJson = new XiaomanCustomerInfoJson();
                    xiaomanCustomerInfoJson.setCompanyId(customer.getCompanyId());
                    xiaomanCustomerInfoJson.setJson(customerDetailJson);
                    xiaomanCustomerInfoJsonService.updateById(xiaomanCustomerInfoJson);
                    //TODO 更新数据
                    CustomerInfoVo infoVo = HandleXiaomanData.handleDate(customerDetailJson, new TypeReference<R<CustomerInfoVo>>() {
                    });
                    System.out.println("1");
                }else {
                    save(customer);
                    //TODO 获取详情
                    String customerDetailJson = HandleXiaomanData.getCustomerDetail(customer.getCompanyId());
                    XiaomanCustomerInfoJson xiaomanCustomerInfoJson = new XiaomanCustomerInfoJson();
                    xiaomanCustomerInfoJson.setCompanyId(customer.getCompanyId());
                    xiaomanCustomerInfoJson.setJson(customerDetailJson);
                    xiaomanCustomerInfoJsonService.save(xiaomanCustomerInfoJson);

                    //TODO 更新数据
                    CustomerInfoVo infoVo = HandleXiaomanData.handleDate(customerDetailJson, new TypeReference<R<CustomerInfoVo>>() {
                    });
                    System.out.println("2");
                }
            }catch (Exception e){
               e.printStackTrace();
            }
        }


    }
}
